@@ -7,8 +7,16 @@
 # @License: GNU Lesser General Public License v3.0
 
 """
-Notes:
-    this part is a customization from deap.
+Base objects for symbolic regression.
+
+Contains:
+  - Class: ``SymbolSet``
+
+  - Class: ``CalculatePrecisionSet``
+
+  - Class: ``SymbolTree``
+
+  - others
 """
 
 import copy
@@ -34,7 +42,7 @@ from bgp.probability.preference import PreMap
 
 
 class SymbolTerminal:
-    """General feature type.\n
+    """General feature type, do not use directly.\n
     The name for show (str) and calculation (repr) are set to different string for
     avoiding repeated calculations.
     """
@@ -48,9 +56,9 @@ class SymbolTerminal:
             Represent name. Default "xi".
         init_name: str
             Just for show, rather than calculate.\n
-            Examples:\n
-            init_name=[x1,x2] , if is compact features, need[]\n
-            init_name=(x1*x4-x3), if is expr, need ()
+            Examples:
+                init_name=[x1, x2] , if is compact features, need[].\n
+                init_name=(x1*x4-x3), if is expr, need ().
         """
         self.name = str(name)
         self.conv_fct = str
@@ -61,7 +69,7 @@ class SymbolTerminal:
             self.init_name = str(init_name)
 
     def format_repr(self):
-        # short,repr
+        # short, repr
         """representing name"""
         return self.conv_fct(self.name)
 
@@ -103,21 +111,21 @@ class SymbolTerminalDetail(SymbolTerminal):
         Parameters
         ----------
         values: None, number or np.ndarray
-            xi value, the shape can be (n,) or (n_x,n),
+            xi value, the shape can be (n, ) or (n_x, n), 
             n is number of samples, n_x is numbers of feature.
         name: str
             Represent name. Default "xi"
         dim: bgp.dim.Dim or None
-            None
+            None.
         prob: float or None
-            None
+            None.
         init_sym: list, sympy.Expr
-            list
+            list.
         init_name: str or None 
             Just for show, rather than calculate.\n
-            Examples:\n
-            init_name="[x1,x2]" , if is compact features, need[]\n
-            init_name="(x1*x4-x3)", if is expr, need ()
+            Examples:
+                init_name="[x1, x2]" , if is compact features, need[].\n
+                init_name="(x1*x4-x3)", if is expr, need ().
         """
         super(SymbolTerminalDetail, self).__init__(name, init_name)
         if prob is None:
@@ -134,7 +142,7 @@ class SymbolTerminalDetail(SymbolTerminal):
         return SymbolTerminal(self.name, self.init_name)
 
 
-def tsum(*ters, name="gx0"):
+def _tsum(*ters, name="gx0"):
     """
 
     Parameters
@@ -142,7 +150,7 @@ def tsum(*ters, name="gx0"):
     ters: tuple of SymbolTerminalDetail
         SymbolTerminalDetail
     name: str
-        sepcific the name of results.
+        specific the name of results.
 
     Returns
     -------
@@ -163,16 +171,20 @@ def tsum(*ters, name="gx0"):
 
 
 class SymbolPrimitive:
-    """General operation type"""
+    """General operator type, do not use directly,
+    but use SymbolPrimitiveDetail."""
 
     def __init__(self, name, arity):
         """
+
         Parameters
         ----------
         name: str
-            function name
+            function name.
         arity: int
-            function input numbers
+            input parameters numbers of function.
+            such as ``+`` with 2, ``ln`` with 1.
+
         """
         self.name = str(name)
         self.arity = arity
@@ -199,21 +211,26 @@ class SymbolPrimitive:
 
 
 class SymbolPrimitiveDetail(SymbolPrimitive):
+    """
+    General operator type with more details.
+    """
+
     def __init__(self, name, arity, func, prob, np_func=None, dim_func=None, sym_func=None):
         """
         Parameters
         ----------
+
         func: Callable
-            function. Better for sympy.Function Type.\n
+            function. better using sympy.Function Type.\n
             For Maintainer:
-            If self function and can not be simplified to sympy.Function or elementary function,
-            the function for function.np_map() and dim.dim_map() should be defined.
+                If self function and can not be simplified to sympy.Function or elementary function, 
+                the function for function.np_map() and dim.dim_map() should be defined.
         name: str
-            function name
+            function name.
         arity: int
-            function input numbers
+            function input numbers.
         prob: float
-            default 1
+            default 1.
         """
         super(SymbolPrimitiveDetail, self).__init__(name, arity)
 
@@ -226,16 +243,23 @@ class SymbolPrimitiveDetail(SymbolPrimitive):
         self.sym_func = sym_func
 
     def capsule(self):
+        """return short one."""
         return SymbolPrimitive(self.name, self.arity)
 
 
 class SymbolSet(object):
     """
-    Definite the operations, features, and fixed constants.
+    Definite the preparation set of operations, features, and fixed constants.
     """
 
     def __init__(self, name="PSet"):
-        """Definite the preparation set of operations, features, and fixed constants."""
+        """
+
+        Parameters
+        ----------
+        name: str
+            name.
+        """
         self.arguments = []  # for translate
         self.name = name
         self.y = None  # data y
@@ -269,12 +293,12 @@ class SymbolSet(object):
         self.gro_ter_con = {}  # for group size calculation and simple
 
         self.terminals_init_map = {}  # for Tree show
-        # terminals representing name "gx0" to represented name "[x1,x2]",
-        # or "newx0" to represented name "Add(Mul(x2,x4)+[x1,x2])".
+        # terminals representing name "gx0" to represented name "[x1, x2]", 
+        # or "newx0" to represented name "Add(Mul(x2, x4)+[x1, x2])".
 
         self.terminals_symbol_map = {}  # for Tree show
-        # terminals representing name "gx0" to represented name "[x1,x2]",
-        # or "newx0" to represented name "Add(Mul(x2,x4)+[x1,x2])".
+        # terminals representing name "gx0" to represented name "[x1, x2]", 
+        # or "newx0" to represented name "Add(Mul(x2, x4)+[x1, x2])".
 
         self.expr_init_map = {}  # for expr show
         # terminals representing name "newx0" to represented name "(x2*x4+gx0)"
@@ -298,7 +322,7 @@ class SymbolSet(object):
             function name
         func: Callable
             function. Better for sympy.Function Type.
-            If self function and can not be simplified to sympy.Function or elementary function,
+            If self function and can not be simplified to sympy.Function or elementary function, 
             the function for np_func and dim_func should be defined.
         arity: int
             function input numbers
@@ -335,7 +359,7 @@ class SymbolSet(object):
             function name
         func: Callable
             function. Better for sympy.Function Type.
-            If self function and can not be simplified to sympy.Function or elementary function,
+            If self function and can not be simplified to sympy.Function or elementary function, 
             the function for np_func and dim_func should be defined.
         arity: 1
             function input numbers, must be 1
@@ -373,7 +397,7 @@ class SymbolSet(object):
         init_name: str
             True name can be found of input. Just for show, rather than calculate.
             Examples:
-            init_name="[x1,x2]" , if is compact features, need[]
+            init_name="[x1, x2]" , if is compact features, need[]
             init_name="(x1*x4-x3)", if is expr, need ()
         dim: Dim
             xi Dim
@@ -391,15 +415,15 @@ class SymbolSet(object):
 
     def register(self, primitives_dict="all", dispose_dict="all", ter_con_dict="all"):
         """
-        Register and capsule for simpify.
+        Register and capsule for simplify.
         
         Parameters
         ----------
-        primitives_dict:None,str,dict
+        primitives_dict:None, str, dict
         
-        dispose_dict:None,str,dict
+        dispose_dict:None, str, dict
         
-        ter_con_dict:None,str,dict
+        ter_con_dict:None, str, dict
 
         """
         if primitives_dict == "all":
@@ -462,7 +486,7 @@ class SymbolSet(object):
         if not x_group:
             x_group = self.x_group
         if isinstance(x_group, int):
-            assert self.terms_count > x_group > 1, "the len of group should in (2,x.shape[1]]"
+            assert self.terms_count > x_group > 1, "the len of group should in (2, x.shape[1]]"
             indexes = [_ for _ in range(self.terms_count)]
             x_group = [indexes[i:i + x_group] for i in range(0, len(indexes), x_group)]
 
@@ -474,7 +498,7 @@ class SymbolSet(object):
                 init_ter_name = ["x%s" % j for j in gi]
                 init_ter = [self.ter_con_dict.pop(i) for i in init_ter_name]
                 name = "gx%s" % i
-                ter = tsum(*init_ter, name=name)
+                ter = _tsum(*init_ter, name=name)
                 self.ter_con_dict[name] = ter
 
                 self.terms_count -= (len(init_ter) - 1)
@@ -512,47 +536,54 @@ class SymbolSet(object):
 
         Parameters
         ----------
-
-        power_categories: Sized,tuple, None
-            Examples:(0.5,2,3)
+        power_categories: Sized, tuple, None
+            Examples:
+                (0.5, 2, 3)
         categories: tuple of str
             map table:
-                    {"Add": sympy.Add, 'Sub': Sub, 'Mul': sympy.Mul, 'Div': Div}
+                {'Add': sympy.Add, 'Sub': Sub, 'Mul': sympy.Mul, 'Div': Div}
+                {"sin": sympy.sin, 'cos': sympy.cos, 'exp': sympy.exp, 'ln': sympy.ln, }
+                {'Abs': sympy.Abs, "Neg": functools.partial(sympy.Mul, -1.0), }
+                "Rec": functools.partial(sympy.Pow, e=-1.0)}
 
-                    {"sin": sympy.sin, 'cos': sympy.cos, 'exp': sympy.exp, 'ln': sympy.ln,
-
-                    {'Abs': sympy.Abs, "Neg": functools.partial(sympy.Mul, -1.0),
-                    
-                    "Rec": functools.partial(sympy.Pow, e=-1.0)}
-
-                    Others:  \n
-                    "Rem":  f(x)=1-x,if x true \n
-                    "Self":  f(x)=x,if x true \n
-
-        power_categories_prob:"balance", float
-            float in (0,1]
-            probability of power categories, "balance" is 1/n_power_cat
+                Others:  \n
+                "Rem":  f(x)=1-x, if x true \n
+                "Self":  f(x)=x, if x true \n
         categories_prob: "balance", float
-            float in (0,1]
-            probabilityty of categories, except (+,-*,/), "balance" is 1/n_categories.\n
-            Notes: the  (+,-*,/) are set as 1 to be a standard.
-        special_prob: None or dict
-            Examples: {"Mul":0.6,"Add":0.4,"exp":0.1}
-        self_categories:list of dict,None
-            the dict can be generate from newfuncV or defination self.
+            probability of categories, except (+, -*, /), in (0, 1].
+            "balance" is 1/n_categories.
+            The (+, -*, /) are set as 1 to be a standard.
+        special_prob: None, dict
+            prob for special name.\n
+            Examples:{"Mul":0.6, "Add":0.4, "exp":0.1}
+        power_categories_prob: "balance", float
+            float in (0, 1].
+            probability of power categories, "balance" is 1/power_categories_prob.
+        self_categories:list of dict, None
+            the dict can be generate from newfuncV or definition self.\n
             the function at least containing:
-            {"func": func, "name": name, "arity":2,"np_func": npf, "dim_func": dimf, "sym_func": gsymf}
-            func:sympy.Function(name) object
-            name:name
-            arity:int,the number of parameter
-            np_func:numpy function
-            dim_func:dimension function
-            sym_func:NewArray function. (unpack the group,used just for shown)
+            {"func": func, "name": name, "arity":2, "np_func": npf, "dim_func": dimf, "sym_func": gsymf}
+
+            1.func:sympy.Function(name) object
+
+            2.name:name
+
+            3.arity:int, the number of parameter
+
+            4.np_func:numpy function
+
+            5.dim_func:dimension function
+
+            6.sym_func:NewArray function. (unpack the group, used just for shown)
+
             See Also bgp.newfunc.newfuncV
-        Returns
-        -------
-        SymbolSet
         """
+
+        """        
+
+
+
+"""
         if categories is None:
             categories = ("Add", "Mul", "Self", "exp")
 
@@ -572,7 +603,7 @@ class SymbolSet(object):
             elif isinstance(power_categories_prob, float):
                 prob = power_categories_prob
             else:
-                raise TypeError("power_categories_prob accept float from (0,1] or 'balance'.")
+                raise TypeError("power_categories_prob accept float from (0, 1] or 'balance'.")
             for j, i in enumerate(power_categories):
                 name = 'pow%s' % j
                 prob = change(name, prob)
@@ -589,7 +620,7 @@ class SymbolSet(object):
             elif isinstance(categories_prob, float):
                 prob1 = categories_prob
             else:
-                raise TypeError("categories_prob accept float from (0,1] or 'balance'.")
+                raise TypeError("categories_prob accept float from (0, 1] or 'balance'.")
             if i in functions1:
                 prob1 = change(i, prob1)
                 self._add_primitive(functions1[i], arity=1, name=i, prob=prob1)
@@ -609,32 +640,43 @@ class SymbolSet(object):
     def add_accumulative_operation(self, categories=None, categories_prob="balance",
                                    self_categories=None, special_prob=None):
         """
+        add accumulative operation.
 
         Parameters
         ----------
         categories: tuple of str
-            categories=("Self","MAdd","MSub", "MMul","MDiv")
+            categories=("Self", "MAdd", "MSub", "MMul", "MDiv")
         categories_prob: None, "balance" or float.
-            probility of categories  (0,1], except ("Self","MAdd", "MSub", "MMul", "MDiv"),
-            "balance" is 1/n_categories.
-            "MSub", "MMul", "MDiv" only work on the size of group is 2, else work like "Self".
-            Notes: the  ("Self","MAdd","MSub", "MMul", "MDiv") are set as 1 and 0.1 to be a standard.
-        self_categories:list of dict,None
-            the dict can be generate from newfuncD or defination self.
-            the function at least containing:
-            {"func": func, "name": name, "np_func": npf, "dim_func": dimf, "sym_func": gsymf}
-            func:sympy.Function(name) object,which need add attributes: is_jump,keep.
-            name:name
-            np_func:numpy function
-            dim_func:dimension function
-            sym_func:NewArray function. (unpack the group,used just for shown)
-            See Also bgp.newfunc.newfuncV
-        special_prob: None or dict
-            Examples: {"MAdd":0.5,"Self":0.5}
+            probility of categories in (0, 1], except ("Self", "MAdd", "MSub", "MMul", "MDiv"),
 
-        Returns
-        -------
-        SymbolSet
+            "balance" is 1/n_categories.
+
+            "MSub", "MMul", "MDiv" are only worked on the size of group is 2, else work like "Self".
+
+            Notes:
+                the  ("Self", "MAdd", "MSub", "MMul", "MDiv") are set as 1 to be a standard.
+        self_categories:list of dict, None
+            the dict can be generate from newfuncD or defination self.
+
+            the function at least containing:
+
+            {"func": func, "name": name, "np_func": npf, "dim_func": dimf, "sym_func": gsymf}
+
+            1.func:sympy.Function(name) object, which need add attributes: is_jump, keep.
+
+            2.name:name
+
+            3.np_func:numpy function
+
+            4.dim_func:dimension function
+
+            5.sym_func:NewArray function. (unpack the group, used just for shown)
+
+            See Also bgp.newfunc.newfuncV
+
+        special_prob: None or dict
+            Examples:
+                {"MAdd":0.5, "Self":0.5}
         """
 
         def change(n, pp):
@@ -665,7 +707,7 @@ class SymbolSet(object):
         elif isinstance(categories_prob, float):
             prob1 = categories_prob
         else:
-            raise TypeError("categories_prob accept float from (0,1] or 'balance'.")
+            raise TypeError("categories_prob accept float from (0, 1] or 'balance'.")
 
         for i in categories:
 
@@ -695,7 +737,7 @@ class SymbolSet(object):
     def add_tree_to_features(self, Tree, prob=0.3):
         """
         Add the individual as a new feature to initial features.
-        not sure add seccess,because the value and name should be check and
+        not sure add success, because the value and name should be check and
         different to exist.
 
         Parameters
@@ -704,10 +746,6 @@ class SymbolSet(object):
             individual or expression
         prob: int
             probability of this individual
-
-        Returns
-        -------
-        SymbolSet
         """
         try:
             value = Tree.pre_y
@@ -759,23 +797,20 @@ class SymbolSet(object):
         Parameters
         ----------
         X: np.ndarray
-            2D data
+            2D data.
         y: np.ndarray
-            1D data
+            1D data.
         feature_name: None, list of str
-            the same size wih x.shape[1]
+            the same size wih x.shape[1].
         x_dim: 1 or list of Dim
-            the same size wih x.shape[1], default 1 is dless for all x
-        y_dim: 1,Dim
-            dim of y
-        x_prob: None,list of float
-            the same size wih x.shape[1]
+            the same size wih x.shape[1], default 1 is dless for all x.
+        y_dim: 1, Dim
+            dim of y.
+        x_prob: None, list of float
+            the same size wih x.shape[1].
         x_group: None or list of list, int
-            features group
+            features group.
 
-        Returns
-        -------
-        SymbolSet
         """
         X = X.astype(np.float32)
         y = y.astype(np.float32)
@@ -844,8 +879,8 @@ class SymbolSet(object):
                 v = v.astype(np.float32)
                 self._add_terminal(np.array(v), name=v)
 
-        assert old == self.terms_count, "the new X (test,predict) should be with the " \
-                                        "same shape[1] with old X (fit,train). when use re_tree," \
+        assert old == self.terms_count, "the new X (test, predict) should be with the " \
+                                        "same shape[1] with old X (fit, train). when use re_tree, " \
                                         "the tree_X should be offered"
 
         self.register(primitives_dict=None, dispose_dict=None, ter_con_dict="all")
@@ -860,15 +895,11 @@ class SymbolSet(object):
         Parameters
         ----------
         c_dim: 1, list of Dim
-            the same size wih c
-        c: float,list
-            list of float
+            the same size wih c.
+        c: float, list
+            list of float.
         c_prob: None, float, list of float
-            the same size wih c
-
-        Returns
-        -------
-        SymbolSet
+            the same size with c.
         """
         if isinstance(c, float):
             c = [c, ]
@@ -895,6 +926,7 @@ class SymbolSet(object):
 
     def add_features_and_constants(self, X, y, c=None, x_dim=1, y_dim=1, c_dim=1, x_prob=None,
                                    c_prob=None, x_group=None, feature_name=None):
+        """combination of add_constant and add_features."""
         self.add_features(X, y, x_dim=x_dim, y_dim=y_dim, x_prob=x_prob, x_group=x_group,
                           feature_name=feature_name, )
         if c is not None:
@@ -902,32 +934,32 @@ class SymbolSet(object):
 
     def set_personal_maps(self, pers):
         """
-        Personal preference add to permap. more control can be found by pset.premap.***\n
+        personal preference add to permap. more control can be found by pset.premap.***\n
         Just set couples of points and don't chang others.
 
         Parameters
         ----------
         pers : list of list
             Examples:
-                [[index1,index2,prob]]
-                the prob in [0,1).
+                [[index1, index2, prob]],
+                the prob in [0, 1).
         """
         for i in pers:
             self.premap.set_sigle_point(*i)
 
     def bonding_personal_maps(self, pers):
         """
-        Personal preference add to permap. more control can be found by pset.premap.***\n
+        Personal preference add to permap more control can be found by pset.premap\n
         Bond the points with ratio. the others would be penalty.\n
-        For example set the [1,2,0.9],
-        the others bond such as (1,2),(1,3),(1,4)...(2,3),(2,4)...would be with small prob.
+        For example set the [1, 2, 0.9], 
+        the others bond such as (1, 2), (1, 3), (1, 4),...,(2, 3), (2, 4)...would be with small prob.
 
         Parameters
         ----------
         pers : list of list
             Examples:
-                [[index1,index2,prob][...]]
-                the prob is [0,1), 1 means the force binding.
+                [[index1, index2, prob][...]]
+                the prob is [0, 1), 1 means the force binding.
         """
         for i in pers:
             self.premap.down_other_point(*i)
@@ -967,6 +999,7 @@ class SymbolSet(object):
 
     @property
     def primitives(self):
+        """operators"""
         return self.get_values(self.primitives_dict, mean=False)
 
     @property
@@ -990,10 +1023,12 @@ class SymbolSet(object):
 
     @property
     def dispose(self):
+        """accumulate operators"""
         return self.get_values(self.dispose_dict, mean=False)
 
     @property
     def terminals_and_constants(self):
+        """terminals_and_constants"""
         return self.get_values(self.ter_con_dict, mean=False)
 
     @property
@@ -1061,7 +1096,7 @@ class _ExprTree(list):
                                  " an incomplete subtree is not allowed in PrimitiveTree."
                                  " A tree is defined as incomplete when some nodes cannot"
                                  " be mapped to any position in the tree, considering the"
-                                 " primitives' arity. For instance, the tree [sub, 4, 5,"
+                                 " primitives' arity. For instance, the tree [sub, 4, 5, "
                                  " 6] is incomplete if the arity of sub is 2, because it"
                                  " would produce an orphan node (the 6).")
         elif val.arity != self[key].arity:
@@ -1122,6 +1157,14 @@ class _ExprTree(list):
             stack.extend([depth + 1] * elem.arity)
         return max_depth
 
+    @property
+    def length(self):
+        return self.__len__()
+
+    @property
+    def h_bgp(self):
+        return (self.height - 1) / 2
+
     @property
     def root(self):
         """Root of the tree, the element 0 of the list.
@@ -1156,7 +1199,9 @@ class _ExprTree(list):
 
 
 class SymbolTree(_ExprTree):
-    """ Individual Tree, each tree is one expression"""
+    """ Individual Tree, each tree is one expression.
+    The SymbolTree is only generated by method: ``genGrow`` and ``genFull``.
+    """
 
     def __init__(self, *arg, **kwargs):
         super(SymbolTree, self).__init__(*arg, **kwargs)
@@ -1191,6 +1236,7 @@ class SymbolTree(_ExprTree):
         return repr(self) == repr(other)
 
     def compress(self):
+        """drop unnecessary attributes"""
 
         [_ExprTree.__delattr__(self, i) for i in ("coef_expr", "coef_pre_y",
                                                   "coef_score", "pure_expr", "pure_pre_y")
@@ -1201,13 +1247,16 @@ class SymbolTree(_ExprTree):
         return [primitive for primitive in self if primitive.arity == 0]
 
     def ter_site(self):
+        """site for feature and constants node"""
         return [i for i, primitive in enumerate(self) if primitive.arity == 0]
 
     def depart(self):
+        """take part the expression"""
         return depart(self)
 
     @property
     def capsule(self):
+        """return the short one"""
         return ShortStr(self)
 
     @classmethod
@@ -1221,9 +1270,11 @@ class SymbolTree(_ExprTree):
         return cls(genFull(pset, min_, max_, per, ))
 
     def to_expr(self, pset):
+        """transformed to sympy.Expr"""
         return compile_context(self, pset.context, pset.gro_ter_con)
 
     def ppprint(self, pset, feature_name=False):
+        """get a user friendly version"""
         return group_str(self, pset, feature_name=feature_name)
 
 
@@ -1247,7 +1298,7 @@ class ShortStr:
 class CalculatePrecisionSet(SymbolSet):
     """
     Add score method to SymbolSet.
-    The object can get from a worked symbolset object.
+    The object can get from a worked ``SymbolSet`` object.
     """
     hasher = str
 
@@ -1262,43 +1313,44 @@ class CalculatePrecisionSet(SymbolSet):
 
         Parameters
         ----------
-        fuzzy : bool
-            fuzzy or not
-        dim_type : object
-            if None, use the y_dim
         pset:SymbolSet
-            SymbolSet
-        scoring: Callbale, default is sklearn.metrics.r2_score
-            See Also sklearn.metrics
-        score_pen: tuple, default is sklearn.metrics.r2_score
-            See Also sklearn.metrics
+            SymbolSet.
+        scoring: Callbale, default is sklearn.metrics.r2_score.
+            See Also sklearn.metrics.
         filter_warning:bool
-            bool
-        score_pen: tuple of 1 or -1
-            1 : best is positive, worse -np.inf \n
-            -1 : best is negative, worse np.inf \n
-            0 : best is positive , worse 0 \n
+            bool.
+        score_pen: tuple of float
+            1 : best is positive, worse -np.inf. \n
+            -1 : best is negative, worse np.inf. \n
+            0 : best is positive , worst is 0. \n
         cal_dim: bool
-            calculate dim or not, if not return dimless
+            calculate dim or not, if not return dless.
         add_coef: bool
-            bool
+            bool.
         inter_add: bool
-            bool
+            bool.
         inner_add: bool
-            bool
+            bool.
+        fuzzy : bool
+            fuzzy or not.
+        dim_type : object
+            if None, use the y_dim.
         n_jobs:int
-            running core
+            running core.
         batch_size:int
-            batch size, advice batch_size*n_jobs = inds/n
+            batch size, advice batch_size*n_jobs = inds.
         tq:bool
-            bool
-        cv:sklearn.model_selection._split._BaseKFold,int
-            the shuffler must be False
-            use cv spilt for score,return the mean_test_score.
-            use cv spilt for predict,return the cv_predict_y.(not be used)
+            bool.
+        cv:sklearn.model_selection._split._BaseKFold, int
+            the shuffler must be False!
+
+            use cv spilt for score, return the mean_test_score.
+
+            use cv spilt for predict, return the cv_predict_y.(not be used)
+
             Notes:
-            if cv and refit, all the data is refit to determination the coefficients.
-            Thus the expression is not compact with the this scores, when re-calculated by this expression
+                if cv and refit, all the data is refit to determination the coefficients.\n
+                Thus the expression is not compact with the this scores, when re-calculated by this expression
 
         details:bool
             return the expr and predict y cor not.
@@ -1309,7 +1361,6 @@ class CalculatePrecisionSet(SymbolSet):
         score_object:
             score by y or delta y (for implicit function).
 
-
         """
         super(CalculatePrecisionSet, self).__init__()
         self.__dict__.update(copy.deepcopy(pset.__dict__))
@@ -1345,10 +1396,11 @@ class CalculatePrecisionSet(SymbolSet):
         self.scoring = scoring
 
     def update(self, pset):
+        """updata self by input pset."""
         self.__dict__.update(copy.deepcopy(pset.__dict__))
 
     def update_with_X_y(self, X, y):
-
+        """replace x, y data."""
         if self.expr_init_map:
             tree_x = []
             n = len(self.expr_init_map)
@@ -1367,6 +1419,7 @@ class CalculatePrecisionSet(SymbolSet):
             self.replace(X, y=y)
 
     def compile_context(self, ind):
+        """transform SymbolTree to sympy.Expr."""
         if isinstance(ind, SymbolTree):
             expr = compile_context(ind.capsule, self.context, self.gro_ter_con)
         else:
@@ -1374,7 +1427,7 @@ class CalculatePrecisionSet(SymbolSet):
         return expr
 
     def calculate_cv_score(self, ind):
-        """Haven't been used, just used for calculating single one or check."""
+        """just used for calculating single one or check."""
         if isinstance(ind, SymbolTree):
             expr = compile_context(ind.capsule, self.context, self.gro_ter_con)
         elif isinstance(ind, sympy.Expr):
@@ -1394,20 +1447,26 @@ class CalculatePrecisionSet(SymbolSet):
         return score, expr01, pre_y
 
     def calculate_score(self, ind):
+        """
+        just used for calculating single one or check with cv=1.
+
+        Parameters
+        ----------
+        ind:SymbolTree
+        """
         self.cv = 1
         return self.calculate_cv_score(ind)
 
     def calculate_detail(self, ind):
         """
-        This is not used when paralleling, just used for calculated final results for showing.
+        just used for calculated final best one result for showing.
+
+        calculate the best expression.
 
         Parameters
         ----------
         ind: SymbolTree
-
-        Returns
-        -------
-        SymbolTree
+            best expression.
         """
         ind = self.calculate_simple(ind)
 
@@ -1434,15 +1493,13 @@ class CalculatePrecisionSet(SymbolSet):
 
     def calculate_simple(self, ind):
         """
-        This is not used when paralleling, just used for re_Tree, and showing
+        just used for re_Tree, and showing.
+
+        calculate the best expression.
 
         Parameters
         ----------
         ind:SymbolTree
-
-        Returns
-        -------
-        SymbolTree
         """
         if isinstance(ind, SymbolTree):
             expr = compile_context(ind.capsule, self.context, self.gro_ter_con)
@@ -1475,15 +1532,12 @@ class CalculatePrecisionSet(SymbolSet):
 
     def calculate_expr(self, expr):
         """
-        This is not used when paralleling, just used for calculated final results for showing.
+        just used for calculated final result for showing.
 
         Parameters
         ----------
-        ind:sympy.expr
+        ind:sympy.Expr
 
-        Returns
-        -------
-        dict
         """
 
         if isinstance(expr, sympy.Expr):
@@ -1512,6 +1566,7 @@ class CalculatePrecisionSet(SymbolSet):
         return result
 
     def parallelize_calculate_expr(self, exprs):
+        """just used for final results, calculate exprs."""
 
         calls = functools.partial(calculate_cv_score, x=self.data_x, y=self.y,
                                   terminals_and_constants_repr=self.terminals_and_constants_repr,
@@ -1530,6 +1585,7 @@ class CalculatePrecisionSet(SymbolSet):
         return score_dim_list
 
     def try_add_coef_times(self, expr, grid_x=None):
+        """just used for best result, try add coefficient to expr."""
 
         pre_y_all_expr01 = try_add_coef_times(expr, self.data_x, self.y, self.terminals_and_constants_repr, grid_x,
                                               filter_warning=self.filter_warning, inter_add=self.inter_add,
@@ -1544,6 +1600,7 @@ class CalculatePrecisionSet(SymbolSet):
         return pre_y_all_expr01
 
     def parallelize_try_add_coef_times(self, exprs, grid_x=None, resample_number=500):
+        """to be continued"""
         if isinstance(grid_x, np.ndarray):
             grid_x = list(grid_x.T)
         calls = functools.partial(try_add_coef_times, x=self.data_x, y=self.y,
@@ -1566,14 +1623,12 @@ class CalculatePrecisionSet(SymbolSet):
 
     def parallelize_score(self, inds):
         """
+        The main score in each generation of GP!
 
         Parameters
         ----------
         inds:list of SymbolTree
-
-        Returns
-        -------
-        list of (score,dim,dim_score)
+            list of expressions
 
         """
 
